@@ -588,6 +588,43 @@ ID要强调当下分解的多样性？因为走势本身就是当下形成中的
 
 --摘自《2008-02-03 10:03 教你打坐23：“任”病最缠人》
 """,
+
+    "66": """
+1. 恐惧和贪婪，都源自对市场的无知。
+2. 股票都是废纸，你要的不是任何股票，而是通过股票把血抽出来。
+3. 一个坏习惯足以毁掉一切，每次操作后一定要不断总结，逐步提高。
+4. 不要有依赖心理，只有自己在实践中成为自己一部分的，才是真实的。
+
+--摘自《2007-01-31 15:13 来这里，首先要洗心革面》
+""",
+
+    "67": """
+以中长线的心态选择股票，短线全部用纯技术把成本变成负数，这才能永远不败。
+
+--摘自《2007-01-31 15:13 来这里，首先要洗心革面》评论
+""",
+
+    "68": """
+没有什么是不可以的，但必须知道代价以及能够去承受这代价。
+那些又要玩刀又怕被刀杀着的，回家玩豆腐吧。
+
+--摘自《2007-08-31 16:04 刀锋上的行走》
+""",
+
+    "69": """
+死亡，就是生命真相的一个大揭露。一切在生时抓住的东西，一旦死亡到来，都不管用了，你什
+么都抓不住。死亡，赋予生命以意义。你在生命中牵连的一切，在死亡中被意义了。死亡，照亮
+了生命。没有死亡，生命没有了意义。
+
+--摘自《2007-09-02 11:00 教你打坐6：于死亡而从容》
+""",
+
+    "70": """
+莫问为何，接受走势。走势即因，走势亦果。
+
+--摘自《即缠非缠》微博 2022-02-17
+""",
+
 }
 
 
