@@ -52,7 +52,7 @@ class TsDataCache:
         self.api_names = [
             'ths_daily', 'ths_index', 'ths_member', 'pro_bar',
             'hk_hold', 'cctv_news', 'daily_basic', 'index_weight',
-            'adj_factor', 'pro_bar_minutes', 'limit_list'
+            'adj_factor', 'pro_bar_minutes', 'limit_list', 'bak_basic'
         ]
         self.api_path_map = {k: os.path.join(cache_path, k) for k in self.api_names}
 
@@ -83,6 +83,8 @@ class TsDataCache:
             kline = pro.ths_daily(ts_code=ts_code, start_date=self.sdt, end_date=self.edt,
                                   fields='ts_code,trade_date,open,close,high,low,vol')
             kline = kline.sort_values('trade_date', ignore_index=True)
+            kline['trade_date'] = pd.to_datetime(kline['trade_date'], format=self.date_fmt)
+            kline['dt'] = kline['trade_date']
 
             for bar_number in (1, 2, 3, 5, 8, 13, 21, 34, 55, 89, 144, 233, 377):
                 # 向后看
@@ -166,6 +168,8 @@ class TsDataCache:
                                start_date=start_date_, end_date=self.edt)
             kline = kline.sort_values('trade_date', ignore_index=True)
             kline['trade_date'] = pd.to_datetime(kline['trade_date'], format=self.date_fmt)
+            kline['dt'] = kline['trade_date']
+            kline['avg_price'] = kline['amount'] / kline['vol']
 
             for bar_number in (1, 2, 3, 5, 8, 13, 21, 34, 55, 89, 144, 233, 377):
                 # 向后看
@@ -228,6 +232,8 @@ class TsDataCache:
             kline = df_klines.drop_duplicates('trade_time')\
                 .sort_values('trade_time', ascending=True, ignore_index=True)
             kline['trade_time'] = pd.to_datetime(kline['trade_time'], format=dt_fmt)
+            kline['dt'] = kline['trade_time']
+            kline['avg_price'] = kline['amount'] / kline['vol']
 
             # 删除9:30的K线
             kline['keep'] = kline['trade_time'].apply(lambda x: 0 if x.hour == 9 and x.minute == 30 else 1)
@@ -409,6 +415,28 @@ class TsDataCache:
             io.save_pkl(df, file_cache)
         return df
 
+    def bak_basic(self, trade_date: str = None, ts_code: str = None):
+        """https://tushare.pro/document/2?doc_id=262
+
+        :param trade_date: 交易日期
+        :param ts_code: 标的代码
+        :return:
+        """
+        assert trade_date or ts_code, "请至少设定一个参数，trade_date 或 ts_code"
+
+        if trade_date:
+            trade_date = pd.to_datetime(trade_date).strftime("%Y%m%d")
+
+        cache_path = self.api_path_map['bak_basic']
+        file_cache = os.path.join(cache_path, f"bak_basic_{trade_date}_{ts_code}.pkl")
+
+        if os.path.exists(file_cache):
+            df = io.read_pkl(file_cache)
+        else:
+            df = pro.bak_basic(trade_date=trade_date, ts_code=ts_code)
+            io.save_pkl(df, file_cache)
+        return df
+
     # ------------------------------------CZSC 加工接口----------------------------------------------
 
     def get_all_ths_members(self, exchange="A", type_="N"):
@@ -454,8 +482,29 @@ class TsDataCache:
             ntd = trade_dates[i + n]
             return ntd
         else:
-            assert abs(m) > abs(n), "abs(m) 必须大于 abs(n)"
-            ntd_list = trade_dates[i+n: i+m]
+            assert m > n > 0 or m < n < 0, "abs(m) 必须大于 abs(n)"
+            if m > n > 0:
+                ntd_list = trade_dates[i+n: i+m]
+            else:
+                ntd_list = trade_dates[i+m: i+n]
             return ntd_list
 
+    def get_dates_span(self, sdt: str, edt: str, is_open: bool = True) -> List[str]:
+        """获取日期区间列表
+
+        :param sdt: 开始日期
+        :param edt: 结束日期
+        :param is_open: 是否是交易日
+        :return: 日期区间列表
+        """
+        sdt = pd.to_datetime(sdt).strftime("%Y%m%d")
+        edt = pd.to_datetime(edt).strftime("%Y%m%d")
+
+        trade_cal = self.trade_cal()
+        if is_open:
+            trade_cal = trade_cal[trade_cal['is_open'] == 1]
+
+        trade_dates = [x for x in trade_cal['cal_date'] if edt >= x >= sdt]
+        return trade_dates
+
 
