@@ -203,55 +203,3 @@ def get_s_sma(c: analyze.CZSC, di: int = 1, t_seq=(5, 10, 20, 60)) -> OrderedDic
     return s
 
 
-def get_s_bar_end(c: analyze.CZSC) -> OrderedDict:
-    """K线结束时间判断"""
-    freq: Freq = c.freq
-    if freq != Freq.F1:
-        return OrderedDict()
-
-    s = OrderedDict()
-    default_signals = [
-        Signal(k1="5分钟", k2="倒1K", k3="结束", v1="其他", v2='其他', v3='其他'),
-        Signal(k1="15分钟", k2="倒1K", k3="结束", v1="其他", v2='其他', v3='其他'),
-        Signal(k1="30分钟", k2="倒1K", k3="结束", v1="其他", v2='其他', v3='其他'),
-        Signal(k1="60分钟", k2="倒1K", k3="结束", v1="其他", v2='其他', v3='其他'),
-        Signal(k1="日线", k2="倒1K", k3="结束", v1="其他", v2='其他', v3='其他'),
-
-        Signal(k1="股票", k2="开仓", k3="时间范围A", v1="其他", v2='其他', v3='其他'),
-        Signal(k1="股票", k2="开仓", k3="时间范围B", v1="其他", v2='其他', v3='其他'),
-        Signal(k1="股票", k2="开仓", k3="时间范围C", v1="其他", v2='其他', v3='其他'),
-        Signal(k1="股票", k2="开仓", k3="时间范围D", v1="其他", v2='其他', v3='其他'),
-    ]
-    for signal in default_signals:
-        s[signal.key] = signal.value
-
-    dt: datetime = c.bars_raw[-1].dt
-    for i in [5, 15, 30, 60]:
-        if dt.minute % i == 0:
-            v = Signal(k1=f"{i}分钟", k2="倒1K", k3="结束", v1="是")
-        else:
-            v = Signal(k1=f"{i}分钟", k2="倒1K", k3="结束", v1="否")
-        s[v.key] = v.value
-
-    if dt.hour == 14 and 45 < dt.minute < 56:
-        v = Signal(k1="日线", k2="倒1K", k3="结束", v1="是")
-        s[v.key] = v.value
-
-    if "10:00" <= dt.strftime("%H:%M") <= "14:59":
-        v = Signal(k1="股票", k2="开仓", k3="时间范围A", v1="上午十点", v2='下午三点')
-        s[v.key] = v.value
-
-    if "11:00" <= dt.strftime("%H:%M") <= "14:59":
-        v = Signal(k1="股票", k2="开仓", k3="时间范围B", v1="上午十一点", v2='下午三点')
-        s[v.key] = v.value
-
-    if "13:30" <= dt.strftime("%H:%M") <= "14:59":
-        v = Signal(k1="股票", k2="开仓", k3="时间范围C", v1="下午一点半", v2='下午三点')
-        s[v.key] = v.value
-
-    if "14:30" <= dt.strftime("%H:%M") <= "14:59":
-        v = Signal(k1="股票", k2="开仓", k3="时间范围D", v1="下午两点半", v2='下午三点')
-        s[v.key] = v.value
-
-    return s
-
