@@ -7,7 +7,9 @@ create_dt: 2021/12/12 21:49
 import os
 from tqdm import tqdm
 from typing import List, Callable
+from deprecated import deprecated
 
+from ..utils import x_round
 from ..utils.bar_generator import BarGenerator
 from ..objects import PositionLong, PositionShort, RawBar
 from .advanced import CzscAdvancedTrader
@@ -89,13 +91,15 @@ def trader_fast_backtest(bars: List[RawBar],
         ct.update(bar)
         if ct.long_pos and ct.long_pos.pos_changed and html_path:
             op = ct.long_pos.operates[-1]
-            file_html = os.path.join(html_path, f"{op['op'].value}_{op['bid']}_{op['price']}_{op['op_desc']}.html")
+            file_name = f"{op['op'].value}_{op['bid']}_{x_round(op['price'], 2)}_{op['op_desc']}.html"
+            file_html = os.path.join(html_path, file_name)
             ct.take_snapshot(file_html)
             print(f'snapshot saved into {file_html}')
 
         if ct.short_pos and ct.short_pos.pos_changed and html_path:
             op = ct.short_pos.operates[-1]
-            file_html = os.path.join(html_path, f"{op['op'].value}_{op['bid']}_{op['price']}_{op['op_desc']}.html")
+            file_name = f"{op['op'].value}_{op['bid']}_{x_round(op['price'], 2)}_{op['op_desc']}.html"
+            file_html = os.path.join(html_path, file_name)
             ct.take_snapshot(file_html)
             print(f'snapshot saved into {file_html}')
 
@@ -119,6 +123,7 @@ def trader_fast_backtest(bars: List[RawBar],
     return res
 
 
+@deprecated(reason="请使用 czsc.traders.utils.trader_fast_backtest 代替", version="1.0.0")
 def fast_back_test(bars: List[RawBar],
                    init_n: int,
                    strategy: Callable,
